// Copyright 2012 Google Inc. All Rights Reserved.

/**
 * @fileoverview Methods used to extract and reformat the local metadata for use
 *     in GSA's native rendering of maps results.
 *
 * @author huey@google.com (Andrea Huey)
 */

/**
 * Namespace for this file.
 */
var gmaMaps = gmaMaps || {};

/**
 * Scrape the dom for addresses and phone numbers for local results.
 * @return {Object} Dictionary. Each marker has an address and phone attribute.
 */
gmaMaps.getAddressesAndPhoneNumbers = function() {
  var searchBlock = google.dom.getAll('#search')[0];
  var addresses = google.dom.getAll('.address', searchBlock);
  var phoneNumbers = google.dom.getAll('.phone', searchBlock);

  // TODO(huey): Handle records with missing address or phone number. This is
  // a hacky way to scrape the DOM, but this will be addressed when we move to a
  // more reliable microdata format.
  if (addresses.length == 0 || addresses.length != phoneNumbers.length) {
    return null;
  }

  var output = [];
  for (var counter = 0; counter < addresses.length; counter++) {
    // Tagged elements are spans.
    var marker = {};
    marker['address'] = addresses[counter].innerText;
    marker['phone'] = phoneNumbers[counter].innerText;
    output.push(marker);
  }
  return output;
};

/**
 * Combines all the metadata about location markers.
 * @param {Object} addressAndPhone Dictionary of markers->(address, phone #).
 * @return {Object} Dictionary of markers->(address, phone, lat, long...).
 */
gmaMaps.addAddressAndPhoneToExtendedData = function(addressAndPhone) {
  var basic = JSON.parse(window.huey_maps_interactive_json);

  // Since the extended json is already labeled by marker, augment it with the
  // other data.
  var mapData = JSON.parse(window.huey_extended_json);

  // Add phone number and address, which were passed in.
  for (var counter = 0; counter < addressAndPhone.length; counter++) {
    var markerLetter = String.fromCharCode(counter + 65);
    mapData[markerLetter]['address'] = addressAndPhone[counter]['address'];
    mapData[markerLetter]['phone'] = addressAndPhone[counter]['phone'];
  }

  // Basic marker data is an array of lat-lng coords in the marker array.
  var basicMarkerData = basic['marker'];
  for (var counter = 0; counter < basicMarkerData.length; counter++) {
    var markerLetter = String.fromCharCode(counter + 65);
    mapData[markerLetter]['lat'] = basicMarkerData[counter]['lat'];
    mapData[markerLetter]['lng'] = basicMarkerData[counter]['lng'];
  }

  return JSON.stringify(mapData);
};
